using Gtk;

public class Main {

  class AppStatusIcon : Window {
    private StatusIcon trayicon;
    private Gtk.Menu menuSystem;

    public AppStatusIcon() {
      /* Create tray icon */
      trayicon = new StatusIcon.from_file("/usr/share/icons/hicolor/64x64/apps/simple-radio.png");
      trayicon.set_tooltip_text ("Simple Radio");
      trayicon.set_visible(true);

      trayicon.activate.connect(icon_clicked);

      create_menuSystem();
      trayicon.popup_menu.connect(menuSystem_popup);
    }

    private void icon_clicked() {
	  print("You have clicked on the icon\n");
	}

    public void play_first() {
      try {
	    Process.spawn_command_line_async(@"mplayer http://stream-tx1.radioparadise.com:8052");
	    Process.spawn_command_line_async(@"notify-send -i simple-radio 'Radio Paradise' http://stream-tx1.radioparadise.com:8052");
      }
      catch (IOError e) {
		stderr.printf ("%s\n", e.message);
      }
    }
    
    public void mplayer_exit() {
      try {
	    Process.spawn_command_line_async(@"killall mplayer");
      }
      catch (IOError e) {
		stderr.printf ("%s\n", e.message);
      }
    }   
    
    /* Create menu for right click */
    public void create_menuSystem() {
      menuSystem = new Gtk.Menu();
      
      var menuPlay = new ImageMenuItem.with_label("Radio Paradise");
      menuPlay.set_image(new Image.from_stock(Gtk.STOCK_MEDIA_PLAY, Gtk.IconSize.SMALL_TOOLBAR));
      menuPlay.activate.connect(play_first);
      menuSystem.append(menuPlay);
      
      var menuSeparator = new SeparatorMenuItem();
      menuSystem.append(menuSeparator);
      
      var menuAbout = new ImageMenuItem.from_stock(Stock.ABOUT, null);
      menuAbout.activate.connect(about_clicked);
      menuSystem.append(menuAbout);
      
      var menuQuit = new ImageMenuItem.from_stock(Stock.QUIT, null);
      menuQuit.activate.connect(mplayer_exit);
      menuQuit.activate.connect(Gtk.main_quit);
      menuSystem.append(menuQuit);
      
      menuSystem.show_all();
    }

    /* Show popup menu */
    private void menuSystem_popup(uint button, uint time) {
      menuSystem.popup(null, null, null, button, time);
    }

    private void about_clicked() {
      var about = new AboutDialog();
      about.set_property("skip-taskbar-hint", true);
      about.set_version("1.1.");
      about.set_program_name("Simple Radio");
      Image aboutlogo = new Image.from_file("/usr/share/icons/hicolor/64x64/apps/simple-radio.png");
      about.set_logo(aboutlogo.get_pixbuf());
      about.set_comments("Play radio streams with mplayer");
      about.set_copyright("Copyright (C) 2013 alphaOS");
      about.set_website("http://sourceforge.net/projects/alphaos");
      about.run();
      about.destroy();
    }
  }

  public static int main (string[] args) {
    Gtk.init(ref args);
    var App = new AppStatusIcon();
    App.hide();
    Gtk.main();
    return 0;
  }
}
